@@ -64,7 +64,7 @@
   #endif
   // Globalize a label defined in the same translation unit.
   // See macro ASM_GLOBALIZE_LABEL in the gcc sources.
-  #if defined(__i386__) || defined(__m68k__) || defined(__mips__) || defined(__mipsel__) || defined(__mips64__) || defined(__alpha__) || defined(__rs6000__) || defined(__x86_64__) || defined(__s390__)
+  #if defined(__i386__) || defined(__m68k__) || defined(__mips__) || defined(__mipsel__) || defined(__mips64__) || defined(__alpha__) || defined(__rs6000__) || defined(__powerpc64__) || defined(__x86_64__) || defined(__s390__)
     // Some m68k systems use "xdef" or "global" or ".global"...
     #define CL_GLOBALIZE_LABEL(label)  __asm__("\t.globl " label);
   #endif
@@ -96,12 +96,20 @@
   #endif
   // Output a label inside a function.
   // See macro ASM_OUTPUT_LABEL in the gcc sources.
-  #if defined(__hppa__)
-    // Some hppa (Linux) systems want `label:', HPUX used to use just `label'.
-    // I tried to find out, but was unable to find the assembler on my HPUX-11
-    // boxen so decided to potentially ditch the support (no joke).  Please
-    // send an email if you can explain to me what's going on! (-rbk. 07/2001)
-    #define CL_OUTPUT_LABEL(label)  ASM_VOLATILE ("\n" label ":")
+  #if defined(__ia64__)
+    // g++-4.0 on IA64 likes to duplicate parts of basic blocks for no good
+    // reason. To avoid an error when a label is defined twice, we can either
+    // append "-Os" to the CXXFLAGS (then g++ does not create redundant
+    // duplicates of basic blocks), or declare the label in a way that may
+    // be redefined.
+    // Why the "nop 0"? Apparently "." refers to the last instruction bundle.
+    // Just ".set label,." would cause the branch to executed unwanted code.
+    // And ".set label,.+16" might not work at the very beginning of a
+    // function. So we spend a nop; it becomes the target of the jump.
+    #define CL_OUTPUT_LABEL(label)  ASM_VOLATILE ("nop 0" "\n" ".set " label ", .")
+  #elif defined(__m68k__)
+    // C.f. IA64 case above.
+    #define CL_OUTPUT_LABEL(label)  ASM_VOLATILE ("nop" "\n" ".set " label ", .")
   #else
     #define CL_OUTPUT_LABEL(label)  ASM_VOLATILE ("\n" label ":")
   #endif
@@ -127,7 +135,8 @@
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp %0@" : : "a" ((void*)(addr)))
   #endif
   #if defined(__mips__) || defined(__mipsel__)
-    #define CL_JUMP_TO(addr)  ASM_VOLATILE("%*j %0" : : "d" ((void*)(addr)))
+    //#define CL_JUMP_TO(addr)  ASM_VOLATILE("%*j %0" : : "d" ((void*)(addr)))
+    #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " ASM_UNDERSCORE_PREFIX #addr)
   #endif
   #if defined(__sparc__) || defined(__sparc64__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("jmp %0\n\tnop" : : "r" ((void*)(addr)))
@@ -142,7 +151,7 @@
   #if defined(__arm__)
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("mov pc,%0" : : "r" ((void*)(addr)))
   #endif
-  #if defined(__rs6000__) || defined(__powerpc__) || defined(__ppc__)
+  #if defined(__rs6000__) || defined(__powerpc__) || defined(__ppc__) || defined(__powerpc64__)
     //#define CL_JUMP_TO(addr)  ASM_VOLATILE("mtctr %0\n\tbctr" : : "r" ((void*)(addr)))
     #define CL_JUMP_TO(addr)  ASM_VOLATILE("b " ASM_UNDERSCORE_PREFIX #addr)
   #endif
