@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N conjugate (const cl_N& x)
 {
@@ -24,3 +26,5 @@ const cl_N conjugate (const cl_N& x)
 		return complex_C(a,-b);
 	}
 }
+
+}  // namespace cln
