@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_R phase (const cl_N& x)
 {
@@ -28,3 +30,5 @@ const cl_R phase (const cl_N& x)
 		return atan(realpart(x),imagpart(x));
 	}
 }
+
+}  // namespace cln
