@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -15,6 +15,8 @@
 #include "cl_DF.h"
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_F cl_float (const cl_I& x, const cl_F& y)
 {
 	floattypecase(y
@@ -24,3 +26,5 @@ const cl_F cl_float (const cl_I& x, const cl_F& y)
 	,	return cl_I_to_LF(x,TheLfloat(y)->len);
 	);
 }
+
+}  // namespace cln
