@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
@@ -15,6 +15,8 @@
 #define MAYBE_INLINE inline
 #include "cl_DF_minusp.cc"
 
+namespace cln {
+
 const cl_DF ffloor (const cl_DF& x)
 {
 	if (minusp(x))
@@ -22,3 +24,5 @@ const cl_DF ffloor (const cl_DF& x)
 	else
 		return ftruncate(x);
 }
+
+}  // namespace cln
