@@ -1,16 +1,18 @@
-// as_cl_SF().
+// cl_SF_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_sfloat.h"
+#include "cln/sfloat.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 inline cl_boolean cl_SF_p (const cl_number& x)
 {
 	if (!x.pointer_p())
@@ -19,7 +21,7 @@ inline cl_boolean cl_SF_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_SF& as_cl_SF (const cl_number& x, const char * filename, int line)
+const cl_SF& cl_SF_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_SF_p(x)) {
 		DeclareType(cl_SF,x);
@@ -27,3 +29,5 @@ const cl_SF& as_cl_SF (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"a short-float number",filename,line);
 }
+
+}  // namespace cln
