@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #include "cl_DS.h"
 #include "cl_I_log.h"
 
+namespace cln {
+
 // Logische Operationen auf Integers:
 // Methode: aus den Lngen der beiden Argumente eine obere Schranke fr
 // die Lnge des Ergebnisses berechnen (das Maximum der beiden Lngen und
@@ -38,3 +40,5 @@ const cl_I logxor (const cl_I& x, const cl_I& y)
           xor_loop_msp(xptr,yptr,n); // mit XOR verknpfen
           return DS_to_I(zptr,n); // Ergebnis als Integer
     }   }}
+
+}  // namespace cln
