@@ -6,8 +6,8 @@
 #include <cln/rational.h>
 #include <cln/float_io.h>
 #include <cln/random.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 using namespace cln;
 
